var createError = require('http-errors');
var express = require('express');
var path = require('path');
var cookieParser = require('cookie-parser');
var logger = require('morgan');
var cors = require('cors')
var indexRouter = require('./routes/index');
var accountRouter = require('./routes/account')
var mainRouter=require('./routes/main/main')
var projectRouter=require('./routes/main/project')
var dataRouter=require('./routes/main/data')
var projectDetailRouter=require('./routes/project/project')
var infoRouter=require('./routes/project/info')
var prepareRouter=require('./routes/project/prepare')
var hazopRouter=require('./routes/project/hazop')
var lopaRouter=require('./routes/project/lopa')
var sifRouter=require('./routes/project/sif')
const server = require("inspector");

var app = express();

// view engine setup
app.set('views', path.join(__dirname, 'views'));
app.set('view engine', 'pug');

app.use(logger('dev'));
app.use(express.json());
app.use(express.urlencoded({ extended: false }));
app.use(cookieParser());
app.use(express.static(path.join(__dirname, 'public')));

console.debug(`webClient:${process.env.webClient}`)

app.use(cors({
  origin:[process.env.webClient,process.env.devClient],
  credentials:true
}))
app.use('/', indexRouter);
app.use('/api/account',accountRouter)
app.use('/api/main',mainRouter,projectRouter,dataRouter)
app.use('/api/project',projectDetailRouter,infoRouter,prepareRouter,hazopRouter,lopaRouter,sifRouter)

// catch 404 and forward to error handler
app.use(function(req, res, next) {
  next(createError(404));
});

// error handler
app.use(function(err, req, res, next) {
  // set locals, only providing error in development
  res.locals.message = err.message;
  res.locals.error = req.app.get('env') === 'development' ? err : {};

  // render the error page
  res.status(err.status || 500);
  res.render('error');
});

// listen for TERM signal .e.g. kill
process.on ('SIGTERM', ()=>{
  console.info('SIGTERM退出')
  process.exit()
});

// listen for INT signal e.g. Ctrl-C
process.on ('SIGINT', ()=>{
  console.info('SIGINT退出')
  process.exit()
});

module.exports = app;
